A program for Bayesian analysis of univariate normal mixtures with an
unknown number of components, implementing the approach of Richardson and Green,
Journal of the Royal Statistical Society, B, 59, 731-792 (1997);
see also the correction in J. R. Statist. Soc. B, 1998, 60, 661).
Computation is by reversible jump Markov chain Monte Carlo; this package is essentially an R interface to the Fortran program
originally written in 1996 for the MCMC sampling, together with some facilities for displaying and summarising the resulting posterior distribution, and reporting the sampler performance.