Learn R Programming

Nmix (version 2.0.5)

print.nmix: Printing for Bayesian Inference on Univariate Normal Mixtures

Description

Printing of various information about nmix object on current output

Usage

# S3 method for nmix
print(x, ...)

Value

x, invisibly; print method for class nmix. Function called for its side effect of printing selected information from x

Arguments

x

nmix object, as output by Nmix function

...

additional arguments to print

Author

Peter J. Green

Details

Currently the information printed consists of the estimated posterior for k and basic parameters of the MCMC simulation: number of sweeps, length of burnin, random number seed to replicate the run, and confirmation of which MCMC moves used (latters s,w,p,a,h,b standing for split/merge, weights, parameters, allocations, hyperparameters and birth/death).

References

Richardson and Green (J. R. Statist. Soc. B, 1997, 59, 731-792; see also the correction in J. R. Statist. Soc. B, 1998, 60, 661)

Examples

Run this code
data(galx)
z<-Nmix('galx',nsweep=10000,nburnin=1000,out="d")
z

Run the code above in your browser using DataLab