| sdrni | R Documentation |
Front-end to standard R random number seed setter, allowing retrospective replication
sdrni(seed)
seed |
non-negative integer random number seed, often 0 for absolute re-initialisation as with |
Using sdrni to initialise random number stream allows a decision to repeat a simulation exactly, presumably with additional outputs, need only be made after seeing results; see Examples
seed if input value is positive, otherwise the value that if used in a subsequent call will deliver exactly the same random numbers
Peter J. Green
sdrni(0)
runif(5)
keep<-sdrni(0)
runif(5)
sdrni(keep)
runif(5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.