| summary.nmix | R Documentation |
Printing of various information from nmix object on current output
## S3 method for class 'nmix'
summary(object, ...)
object |
|
... |
additional arguments to |
Currently the information printed consists of the estimated posterior for k and basic parameters
of the MCMC simulation: number of sweeps, length of burnin, random number seed to replicate the run, and confirmation of which MCMC moves used, and acceptance statistics for each type of trans-dimensional move.
object, invisibly; summary method for class nmix. Function called for its side effect of printing selected information from object
Peter J. Green
Richardson and Green (J. R. Statist. Soc. B, 1997, 59, 731-792; see also the correction in J. R. Statist. Soc. B, 1998, 60, 661)
data(galx)
z<-Nmix('galx',nsweep=10000,nburnin=1000,out="d")
summary(z)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.