Learn R Programming

Nmix (version 2.0.5)

summary.nmix: Summary for Bayesian Inference on Univariate Normal Mixtures

Description

Printing of various information from nmix object on current output

Usage

# S3 method for nmix
summary(object, ...)

Value

object, invisibly; summary method for class nmix. Function called for its side effect of printing selected information from object

Arguments

object

nmix object, as output by Nmix function

...

additional arguments to summary

Author

Peter J. Green

Details

Currently the information printed consists of the estimated posterior for k and basic parameters of the MCMC simulation: number of sweeps, length of burnin, random number seed to replicate the run, and confirmation of which MCMC moves used, and acceptance statistics for each type of trans-dimensional move.

References

Richardson and Green (J. R. Statist. Soc. B, 1997, 59, 731-792; see also the correction in J. R. Statist. Soc. B, 1998, 60, 661)

Examples

Run this code
data(galx)
z<-Nmix('galx',nsweep=10000,nburnin=1000,out="d")
summary(z)

Run the code above in your browser using DataLab